/**
 * ESUP-Portail Commons - Copyright (c) 2006 ESUP-Portail consortium
 * http://sourcesup.cru.fr/projects/esup-commons
 */
package org.esupportail.commons.batch; 

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;

/**
 * A class that prints the version (as the current date).
 */
public class PrintVersion {

	/**
	 * Bean constructor.
	 */
	private PrintVersion() {
		throw new UnsupportedOperationException();
	}

	/**
	 * Print the syntax and exit.
	 */
	private static void syntax() {
		throw new IllegalArgumentException(
				"syntax: " + PrintVersion.class.getSimpleName() + " <file>");
	}
	
	/**
	 * Print the application name and version to a properties file.
	 * @param path the path of the file to write
	 * @throws IOException 
	 */
	private static void print(final String path) throws IOException {
		File file = new File(path);
		if (file.exists() && !file.delete()) {
			throw new IOException("could not delete [" + path + "]");
		}
        FileWriter out = new FileWriter(file);
        out.write("#\n");
        out.write("# " + path + "\n");
        out.write("#\n");
        out.write("# This file was generated by ant target _print-version,\n");
        out.write("# do not edit manually\n");
        out.write("#\n");
        out.write("\n");
        out.write("app.name=esup-commons\n");
        out.write("app.version=" 
        		+ new SimpleDateFormat("yyyyMMdd-HHmm").format(new Timestamp(System.currentTimeMillis())) 
        		+ "\n");
        out.write("app.copyright=Copyright (c) 2006 ESUP-Portail consortium\n");
        out.close();
	}

	/**
	 * Dispatch depending on the arguments.
	 * @param args
	 * @throws IOException 
	 */
	protected static void dispatch(final String[] args) throws IOException {
		switch (args.length) {
		case 1:
			print(args[0]);
			break;
		default:
			syntax();
			break;
		}
	}

	/**
	 * The main method, called by ant.
	 * @param args
	 */
	public static void main(final String[] args) {
		try {
			dispatch(args);
		} catch (Throwable t) {
			t.printStackTrace();
		}
	}

}
